-------------------------------------------------------------------------------
-- Reset synchroniser. Takes the PLL locked input and waits until it is high
-- before taking reset output high.
-- Used to drive reset inputs of all components in QSys system to ensure that
-- they only come out of reset after the PLL has locked.
-- MFROST, March 2016
-------------------------------------------------------------------------------

library IEEE;
use IEEE.Std_Logic_1164.all;
use IEEE.Numeric_Std.all;

--============================================================================--
--================================== ENTITY ==================================--
--============================================================================--
entity reset_sync is
	port (
		Res_N       : in  std_logic;                         
		Clk  		: in  std_logic;             
		PLL_Locked	: in  std_logic;
		PLL_Locked_Passthrough	: out  std_logic;
		Res_N_Out   : out std_logic
	);
end reset_sync;

--============================================================================--
--================================ ARCHITECTURE ==============================--
--============================================================================--
architecture RTL of reset_sync is
  
begin
	reset_on_pll_locked: process (Res_N, Clk)
	begin
		if Res_N = '0' then
			Res_N_Out <= '0';
		elsif Rising_edge(Clk) then
			if PLL_Locked = '1' then
				Res_N_Out <= '1';
			else
				Res_N_Out <= '0';
			end if;
		end if;
	end process reset_on_pll_locked;    
	
	PLL_Locked_Passthrough <= PLL_Locked;
	
end RTL;


