/*
 * power_inc.h 
 * General dumping ground for constants, functions and stuff to support MAIN.C
 *
 */

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// CONSTANTS
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// DEBUG switch
#define DEBUG 0
#define DISPLAY_ADC_MONITOR 0

// VARIOUS DELAYs
#define DISCHARGE_DELAY 10
#define POK_DELAY 30000
#define END_DELAY 60000

// DEFINE bit positions for the NIOS write_reg which maps to FPGA output pins
#define NIOS_OK_LED_OFF	1	//Bit 0
#define ENABLE_GROUP_1 2 	//Bit 1
#define DISCHARGE_1 4		//Bit 2
#define ENABLE_GROUP_2 8 	//Bit 3
#define DISCHARGE_2 16		//Bit 4
#define ENABLE_GROUP_3 32 	//Bit 5
#define DISCHARGE_3 64		//Bit 6
#define ENABLE_GROUP_4 128 	//Bit 7
#define DISCHARGE_4 256		//Bit 8

//DEFINE bit positions for the NIOS input register
#define USER_DIP_SWITCH_1 1 // Bit 1 of input, connected to DIP_SWITCH_1 on the eval board
#define USER_DIP_SWITCH_2 2 // Bit 2 of input, connected to DIP_SWITCH_2 on the eval board
#define POK_GROUP_1 32		// Bit 5
#define POK_GROUP_2 64		// Bit 6
#define POK_GROUP_3 128		// Bit 7
#define POK_GROUP_4 256		// Bit 8

// ADC Parameters
#define VIN_LOW_LIMIT 1730	// With current hardware setup, this corresponds to ~11v
#define VIN_HIGH_LIMIT 2030	// With current hardware setup, this corresponds to ~13v

//NIOS Output write values for all states - precalculated
//This is needed because we just have one OUTPUT register to the FPGA and we need to maintain
// previously set bits within this register. A better method would be to bit shift and AND/OR
// bits (future work!)
#define ALL_OFF 0
#define POWERUP1 2
#define POWERUP2 10
#define POWERUP3 42
#define POWERUP4 170
#define POWERDN4 42
#define DIS4 298
#define POWERDN3 266
#define DIS3 330
#define POWERDN2 322
#define DIS2 338
#define POWERDN1 336
#define DIS1 340
